==> foundation-2.6.1.tgz: package/PageExportPdf/PageExportPdf.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const PageExportPdf = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M94.284 65.553L75.825 52.411a1.255 1.255 0 00-1.312-.093c-.424.218-.684.694-.685 1.173l.009 6.221H57.231c-.706 0-1.391.497-1.391 1.204v11.442c0 .707.685 1.194 1.391 1.194h16.774v6.27c0 .478.184.917.609 1.136s.853.182 1.242-.097l18.432-13.228c.335-.239.477-.626.477-1.038v-.002c0-.414-.144-.8-.481-1.04z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M64.06 78.553h-6.49a1.73 1.73 0 00-1.73 1.73h-.007v3.01H15.191V36.16h17.723a1.73 1.73 0 001.73-1.73V16.707h21.188v36.356h.011a1.728 1.728 0 001.726 1.691h6.49c.943 0 1.705-.754 1.726-1.691h.004V12.5h-.005V8.48a1.73 1.73 0 00-1.73-1.73h-32.87L5.235 32.7v58.819c0 .956.774 1.73 1.73 1.73h57.089a1.73 1.73 0 001.73-1.73v-2.448h.005v-8.79a1.729 1.729 0 00-1.729-1.728z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M21.525 61.862v9.231h2.795v-2.906h2.131c2.159 0 3.321-1.439 3.321-3.156 0-1.73-1.162-3.169-3.321-3.169h-4.926zm5.411 3.169c0 .484-.374.72-.844.72H24.32v-1.453h1.771c.471 0 .845.235.845.733zm4.292-3.169v9.231h4.138c2.893 0 5.052-1.675 5.052-4.623s-2.159-4.608-5.065-4.608h-4.125zm6.352 4.609c0 1.163-.83 2.187-2.228 2.187h-1.329v-4.36h1.342c1.495 0 2.215.927 2.215 2.173zm11.536-2.173v-2.436h-7.003v9.231h2.795v-3.446h4.11v-2.436h-4.11v-.913z"
  }));
});
PageExportPdf.displayName = 'PageExportPdf';
export const PageExportPdfDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/PageExportPdf/PageExportPdf.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var PageExportPdf = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M94.284 65.553L75.825 52.411a1.255 1.255 0 00-1.312-.093c-.424.218-.684.694-.685 1.173l.009 6.221H57.231c-.706 0-1.391.497-1.391 1.204v11.442c0 .707.685 1.194 1.391 1.194h16.774v6.27c0 .478.184.917.609 1.136s.853.182 1.242-.097l18.432-13.228c.335-.239.477-.626.477-1.038v-.002c0-.414-.144-.8-.481-1.04z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M64.06 78.553h-6.49a1.73 1.73 0 00-1.73 1.73h-.007v3.01H15.191V36.16h17.723a1.73 1.73 0 001.73-1.73V16.707h21.188v36.356h.011a1.728 1.728 0 001.726 1.691h6.49c.943 0 1.705-.754 1.726-1.691h.004V12.5h-.005V8.48a1.73 1.73 0 00-1.73-1.73h-32.87L5.235 32.7v58.819c0 .956.774 1.73 1.73 1.73h57.089a1.73 1.73 0 001.73-1.73v-2.448h.005v-8.79a1.729 1.729 0 00-1.729-1.728z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M21.525 61.862v9.231h2.795v-2.906h2.131c2.159 0 3.321-1.439 3.321-3.156 0-1.73-1.162-3.169-3.321-3.169h-4.926zm5.411 3.169c0 .484-.374.72-.844.72H24.32v-1.453h1.771c.471 0 .845.235.845.733zm4.292-3.169v9.231h4.138c2.893 0 5.052-1.675 5.052-4.623s-2.159-4.608-5.065-4.608h-4.125zm6.352 4.609c0 1.163-.83 2.187-2.228 2.187h-1.329v-4.36h1.342c1.495 0 2.215.927 2.215 2.173zm11.536-2.173v-2.436h-7.003v9.231h2.795v-3.446h4.11v-2.436h-4.11v-.913z"
  }));
});
PageExportPdf.displayName = 'PageExportPdf';
export var PageExportPdfDimensions = {
  height: 100,
  width: 100
};
